=== modified file 'debian/changelog'
--- debian/changelog	2013-07-10 12:48:26 +0000
+++ debian/changelog	2013-07-11 04:02:09 +0000
@@ -1,3 +1,27 @@
+ubuntu-ui-toolkit (0.1.46+13.10.20130711-0ubuntu1) saucy; urgency=low
+
+  [ Kaleo ]
+  * Introduce new theme color palette API centralising the definition of
+    the colors used by the widgets to draw themselves. Adapted most
+    widgets to use the theme color palette. The color palette defined in
+    the Ambiance theme is the one from the new visual design. (LP:
+    #1186968, #1197853)
+  * Switch: refresh to match new visual design.
+  * Tabs: more robust binding of the header component.
+  * CheckBox: refresh to match new visual design.
+
+  [ Loïc Molinari ]
+  * Added support for -Werror flagged debug builds and fixed warnings.
+  * [UbuntuShape] Fixed alignment support.
+
+  [ tpeeters ]
+  * Add API tests for MainView.
+
+  [ Ubuntu daily release ]
+  * Automatic snapshot from revision 613
+
+ -- Ubuntu daily release <ps-jenkins@lists.canonical.com>  Thu, 11 Jul 2013 04:02:09 +0000
+
 ubuntu-ui-toolkit (0.1.46+13.10.20130710.1-0ubuntu1) saucy; urgency=low
 
   [ Kaleo ]

=== modified file 'modules/Ubuntu/Components/MainView.qml'
--- modules/Ubuntu/Components/MainView.qml	2013-07-10 19:22:52 +0000
+++ modules/Ubuntu/Components/MainView.qml	2013-07-12 05:22:28 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright 2012 Canonical Ltd.
+ * Copyright 2012-2013 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -133,7 +133,7 @@
       The property holds the application's name, which must be the same as the
       desktop file's name.
       */
-    property string applicationName
+    property string applicationName: ""
 
     /*!
       \qmlproperty color headerColor

=== modified file 'modules/Ubuntu/Components/Tabs.qml'
--- modules/Ubuntu/Components/Tabs.qml	2013-06-27 15:20:12 +0000
+++ modules/Ubuntu/Components/Tabs.qml	2013-07-10 15:59:20 +0000
@@ -191,25 +191,18 @@
     }
 
     /*! \internal */
-    onActiveChanged: internal.updateHeader()
-    /*! \internal */
-    onParentNodeChanged: internal.updateHeader()
-    Component.onCompleted: internal.updateHeader()
-
-    /*! \internal */
     onModelChanged: if (tabs.active && internal.header) internal.header.show()
 
     QtObject {
         id: internal
         property Header header: tabs.__propagated ? tabs.__propagated.header : null
-        onHeaderChanged: internal.updateHeader()
+    }
 
-        function updateHeader() {
-            if (internal.header) {
-                if (tabs.active) internal.header.contents = __headerContents;
-                else internal.header.contents = null;
-            }
-        }
+    Binding {
+        target: internal.header
+        property: "contents"
+        value: tabs.active ? tabs.__headerContents : null
+        when: internal.header
     }
 
     style: Theme.createStyleComponent("TabsStyle.qml", tabs)

=== modified file 'modules/Ubuntu/Components/Themes/Ambiance/CheckBoxStyle.qml'
--- modules/Ubuntu/Components/Themes/Ambiance/CheckBoxStyle.qml	2013-07-10 17:07:06 +0000
+++ modules/Ubuntu/Components/Themes/Ambiance/CheckBoxStyle.qml	2013-07-10 17:34:20 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright 2012 Canonical Ltd.
+ * Copyright 2013 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -18,46 +18,111 @@
 import Ubuntu.Components 0.1
 
 Item {
-    id: visuals
-    // styling properties
-    property color checkedColor: Theme.palette.selected.foreground
-    property color uncheckedColor: Theme.palette.normal.foreground
+    id: checkBoxStyle
 
     /*!
       The image to show inside the checkbox when it is checked.
      */
-    property url checkMarkSource: "artwork/CheckMark.png"
-    /*!
-      The animation to fade the color from checkedColor to uncheckedColor and vice versa.
-     */
-    property PropertyAnimation backgroundColorAnimation: ColorAnimation { duration: UbuntuAnimation.SnapDuration; easing: UbuntuAnimation.StandardEasing }
+    property url tickSource: "artwork/tick.png"
 
-    // code
-    anchors.fill: parent
     opacity: enabled ? 1.0 : 0.5
 
-    implicitWidth: units.gu(4)
+    implicitWidth: units.gu(4.25)
     implicitHeight: units.gu(4)
 
     UbuntuShape {
+        id: background
         anchors.fill: parent
-        color: styledItem.checked ? checkedColor : uncheckedColor
-        Behavior on color {
-            ColorAnimation {
-                duration: backgroundColorAnimation.duration
-                easing: backgroundColorAnimation.easing
-            }
-        }
     }
 
     Image {
-        id: checkMark
+        id: tick
         anchors.centerIn: parent
         smooth: true
-        source: checkMarkSource
-        opacity: styledItem.checked ? 1.0 : 0.0
-        Behavior on opacity {
-            UbuntuNumberAnimation { duration: UbuntuAnimation.SnapDuration }
-        }
+        source: tickSource
+        visible: styledItem.checked || transitionToChecked.running || transitionToUnchecked.running
     }
+
+    state: styledItem.checked ? "checked" : "unchecked"
+    states: [
+        State {
+            name: "checked"
+            PropertyChanges {
+                target: tick
+                anchors.verticalCenterOffset: 0
+            }
+            PropertyChanges {
+                target: background
+                color: Theme.palette.selected.foreground
+            }
+        },
+        State {
+            name: "unchecked"
+            PropertyChanges {
+                target: tick
+                anchors.verticalCenterOffset: checkBoxStyle.height
+            }
+            PropertyChanges {
+                target: background
+                color: Theme.palette.normal.foreground
+            }
+        }
+    ]
+
+    transitions: [
+        Transition {
+            id: transitionToUnchecked
+            to: "unchecked"
+            ColorAnimation {
+                target: background
+                duration: UbuntuAnimation.BriskDuration
+                easing: UbuntuAnimation.StandardEasingReverse
+            }
+            SequentialAnimation {
+                PropertyAction {
+                    target: checkBoxStyle
+                    property: "clip"
+                    value: true
+                }
+                NumberAnimation {
+                    target: tick
+                    property: "anchors.verticalCenterOffset"
+                    duration: UbuntuAnimation.BriskDuration
+                    easing: UbuntuAnimation.StandardEasingReverse
+                }
+                PropertyAction {
+                    target: checkBoxStyle
+                    property: "clip"
+                    value: false
+                }
+            }
+        },
+        Transition {
+            id: transitionToChecked
+            to: "checked"
+            ColorAnimation {
+                target: background
+                duration: UbuntuAnimation.BriskDuration
+                easing: UbuntuAnimation.StandardEasing
+            }
+            SequentialAnimation {
+                PropertyAction {
+                    target: checkBoxStyle
+                    property: "clip"
+                    value: true
+                }
+                NumberAnimation {
+                    target: tick
+                    property: "anchors.verticalCenterOffset"
+                    duration: UbuntuAnimation.BriskDuration
+                    easing: UbuntuAnimation.StandardEasing
+                }
+                PropertyAction {
+                    target: checkBoxStyle
+                    property: "clip"
+                    value: false
+                }
+            }
+        }
+    ]
 }

=== modified file 'modules/Ubuntu/Components/Themes/Ambiance/TabsStyle.qml'
--- modules/Ubuntu/Components/Themes/Ambiance/TabsStyle.qml	2013-07-04 21:36:23 +0000
+++ modules/Ubuntu/Components/Themes/Ambiance/TabsStyle.qml	2013-07-10 20:02:27 +0000
@@ -68,12 +68,6 @@
         NewTabBar {
             id: tabBar
             tabs: theTabs
-            anchors {
-                top: parent ? parent.top : undefined
-                left: parent ? parent.left : undefined
-                right: parent ? parent.right : undefined
-            }
-            //height: tabBarHeight
             headerTextColor: tabsStyle.headerTextColor
             headerTextSelectedColor: tabsStyle.headerTextSelectedColor
             headerTextFadeDuration: tabsStyle.headerTextFadeDuration

=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/PageHeaderBaseDivider@18.png'
Binary files modules/Ubuntu/Components/Themes/Ambiance/artwork/PageHeaderBaseDivider@18.png and modules/Ubuntu/Components/Themes/Ambiance/artwork/PageHeaderBaseDivider@18.png differ
=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/PageHeaderBaseDivider@18.sci'
--- modules/Ubuntu/Components/Themes/Ambiance/artwork/PageHeaderBaseDivider@18.sci	2012-12-12 20:19:12 +0000
+++ modules/Ubuntu/Components/Themes/Ambiance/artwork/PageHeaderBaseDivider@18.sci	1970-01-01 00:00:00 +0000
@@ -1,5 +0,0 @@
-border.top: 4
-border.bottom: 4
-border.left: 0
-border.right: 0
-source: PageHeaderBaseDivider@18.png

=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/TextFieldClear@8.png'
Binary files modules/Ubuntu/Components/Themes/Ambiance/artwork/TextFieldClear@8.png and modules/Ubuntu/Components/Themes/Ambiance/artwork/TextFieldClear@8.png differ
=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_idle@18.png'
Binary files modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_idle@18.png and modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_idle@18.png differ
=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_idle@18.sci'
--- modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_idle@18.sci	2012-11-20 18:57:13 +0000
+++ modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_idle@18.sci	1970-01-01 00:00:00 +0000
@@ -1,5 +0,0 @@
-border.left: 44
-border.top: 54
-border.bottom: 44
-border.right: 52
-source: ubuntushape_medium_radius_idle@18.png
\ No newline at end of file

=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_pressed@18.png'
Binary files modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_pressed@18.png and modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_pressed@18.png differ
=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_pressed@18.sci'
--- modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_pressed@18.sci	2012-11-20 18:57:13 +0000
+++ modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_pressed@18.sci	1970-01-01 00:00:00 +0000
@@ -1,5 +0,0 @@
-border.left: 44
-border.top: 54
-border.bottom: 44
-border.right: 52
-source: ubuntushape_medium_radius_pressed@18.png
\ No newline at end of file

=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_shape@18.png'
Binary files modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_shape@18.png and modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_shape@18.png differ
=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_shape@18.sci'
--- modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_shape@18.sci	2012-11-20 18:57:13 +0000
+++ modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_medium_radius_shape@18.sci	1970-01-01 00:00:00 +0000
@@ -1,5 +0,0 @@
-border.left: 44
-border.top: 54
-border.bottom: 44
-border.right: 52
-source: ubuntushape_medium_radius_shape@18.png
\ No newline at end of file

=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_idle@18.png'
Binary files modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_idle@18.png and modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_idle@18.png differ
=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_idle@18.sci'
--- modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_idle@18.sci	2012-11-20 18:57:13 +0000
+++ modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_idle@18.sci	1970-01-01 00:00:00 +0000
@@ -1,5 +0,0 @@
-border.left: 20
-border.top: 32
-border.bottom: 32
-border.right: 20
-source: ubuntushape_small_radius_idle@18.png
\ No newline at end of file

=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_pressed@18.png'
Binary files modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_pressed@18.png and modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_pressed@18.png differ
=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_pressed@18.sci'
--- modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_pressed@18.sci	2012-11-20 18:57:13 +0000
+++ modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_pressed@18.sci	1970-01-01 00:00:00 +0000
@@ -1,5 +0,0 @@
-border.left: 20
-border.top: 32
-border.bottom: 32
-border.right: 20
-source: ubuntushape_small_radius_pressed@18.png
\ No newline at end of file

=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_shape@18.png'
Binary files modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_shape@18.png and modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_shape@18.png differ
=== removed file 'modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_shape@18.sci'
--- modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_shape@18.sci	2012-11-20 18:57:13 +0000
+++ modules/Ubuntu/Components/Themes/Ambiance/artwork/ubuntushape_small_radius_shape@18.sci	1970-01-01 00:00:00 +0000
@@ -1,5 +0,0 @@
-border.left: 20
-border.top: 32
-border.bottom: 32
-border.right: 20
-source: ubuntushape_small_radius_shape@18.png
\ No newline at end of file

=== modified file 'modules/Ubuntu/Components/Themes/Ambiance/qmldir'
--- modules/Ubuntu/Components/Themes/Ambiance/qmldir	2013-07-01 22:26:49 +0000
+++ modules/Ubuntu/Components/Themes/Ambiance/qmldir	2013-07-05 14:34:00 +0000
@@ -4,7 +4,7 @@
 internal CheckBoxStyle CheckBoxStyle.qml
 internal DialogForegroundStyle DialogForegroundStyle.qml
 internal HeaderStyle HeaderStyle.qml
-internal MainViewStyle MainViewStyle.qml
+MainViewStyle 0.1 MainViewStyle.qml
 internal PointerStyle PointerStyle.qml
 internal PointerStyleShader PointerStyleShader.qml
 internal PopoverForegroundStyle PopoverForegroundStyle.qml

=== added directory 'modules/Ubuntu/Components/Themes/SuruDark'
=== added file 'modules/Ubuntu/Components/Themes/SuruDark/MainViewStyle.qml'
--- modules/Ubuntu/Components/Themes/SuruDark/MainViewStyle.qml	1970-01-01 00:00:00 +0000
+++ modules/Ubuntu/Components/Themes/SuruDark/MainViewStyle.qml	2013-07-05 14:34:00 +0000
@@ -0,0 +1,22 @@
+/*
+ * Copyright 2013 Canonical Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+import QtQuick 2.0
+import Ubuntu.Components.Themes.Ambiance 0.1
+
+MainViewStyle {
+    backgroundSource: ""
+}

=== added file 'modules/Ubuntu/Components/Themes/SuruDark/Palette.qml'
--- modules/Ubuntu/Components/Themes/SuruDark/Palette.qml	1970-01-01 00:00:00 +0000
+++ modules/Ubuntu/Components/Themes/SuruDark/Palette.qml	2013-07-05 14:34:00 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2013 Canonical Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+import QtQuick 2.0
+import Ubuntu.Components.Themes 0.1
+
+Palette {
+    normal: PaletteValues {
+        background: "#221E1C"
+        backgroundText: "#33F3F3E7"
+        base: "#19000000"
+        baseText: "#F3F3E7"
+        foreground: "#888888"
+        foregroundText: "#F3F3E7"
+        overlay: "#F2F2F2"
+        overlayText: "#888888"
+        field: "#19000000"
+        fieldText: "#7F7F7F7F"
+    }
+    selected: PaletteValues {
+        background: "#88D6D6D6" // FIXME: not from design
+        backgroundText: "#F3F3E7"
+        foreground: "#DD4814"
+        foregroundText: "#F3F3E7"
+        field: "#FFFFFF"
+        fieldText: "#888888"
+    }
+}

=== added file 'modules/Ubuntu/Components/Themes/SuruDark/SuruDark.pro'
--- modules/Ubuntu/Components/Themes/SuruDark/SuruDark.pro	1970-01-01 00:00:00 +0000
+++ modules/Ubuntu/Components/Themes/SuruDark/SuruDark.pro	2013-07-11 13:40:11 +0000
@@ -0,0 +1,27 @@
+TEMPLATE = subdirs
+
+uri = Ubuntu.Components.Themes.SuruDark
+installPath = $$[QT_INSTALL_QML]/$$replace(uri, \\., /)
+
+PARENT_THEME_FILE = parent_theme
+QMLDIR_FILE = qmldir
+QML_FILES = *.qml
+ARTWORK_FILES += artwork/*.png \
+                 artwork/*.svg \
+                 artwork/*.sci
+
+parent_theme_file.path = $$installPath
+parent_theme_file.files = $$PARENT_THEME_FILE
+
+qmldir_file.path = $$installPath
+qmldir_file.files = $$QMLDIR_FILE
+
+qml_files.path = $$installPath
+qml_files.files = $$QML_FILES
+
+artwork_files.path = $$installPath/artwork
+artwork_files.files = $$ARTWORK_FILES
+
+
+INSTALLS += parent_theme_file qmldir_file qml_files artwork_files
+OTHER_FILES += $$PARENT_THEME_FILE $$QMLDIR_FILE $$QML_FILES $$ARTWORK_FILES

=== added file 'modules/Ubuntu/Components/Themes/SuruDark/parent_theme'
--- modules/Ubuntu/Components/Themes/SuruDark/parent_theme	1970-01-01 00:00:00 +0000
+++ modules/Ubuntu/Components/Themes/SuruDark/parent_theme	2013-07-05 14:34:00 +0000
@@ -0,0 +1,1 @@
+Ubuntu.Components.Themes.Ambiance

=== added file 'modules/Ubuntu/Components/Themes/SuruDark/qmldir'
--- modules/Ubuntu/Components/Themes/SuruDark/qmldir	1970-01-01 00:00:00 +0000
+++ modules/Ubuntu/Components/Themes/SuruDark/qmldir	2013-07-11 13:26:32 +0000
@@ -0,0 +1,1 @@
+module Ubuntu.Components.Themes.SuruDark

=== added directory 'modules/Ubuntu/Components/Themes/SuruGradient'
=== added file 'modules/Ubuntu/Components/Themes/SuruGradient/MainViewStyle.qml'
--- modules/Ubuntu/Components/Themes/SuruGradient/MainViewStyle.qml	1970-01-01 00:00:00 +0000
+++ modules/Ubuntu/Components/Themes/SuruGradient/MainViewStyle.qml	2013-07-10 19:25:32 +0000
@@ -0,0 +1,22 @@
+/*
+ * Copyright 2013 Canonical Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+import QtQuick 2.0
+import Ubuntu.Components.Themes.Ambiance 0.1
+
+MainViewStyle {
+    backgroundSource: ""
+}

=== added file 'modules/Ubuntu/Components/Themes/SuruGradient/Palette.qml'
--- modules/Ubuntu/Components/Themes/SuruGradient/Palette.qml	1970-01-01 00:00:00 +0000
+++ modules/Ubuntu/Components/Themes/SuruGradient/Palette.qml	2013-07-05 14:34:00 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2013 Canonical Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+import QtQuick 2.0
+import Ubuntu.Components.Themes 0.1
+
+Palette {
+    normal: PaletteValues {
+        background: "#5E2750"
+        backgroundText: "#33F3F3E7"
+        base: "#19000000"
+        baseText: "#F3F3E7"
+        foreground: "#888888"
+        foregroundText: "#F3F3E7"
+        overlay: "#F5F5F5"
+        overlayText: "#888888"
+        field: "#19000000"
+        fieldText: "#7F7F7F7F"
+    }
+    selected: PaletteValues {
+        background: "#88D6D6D6" // FIXME: not from design
+        backgroundText: "#F3F3E7"
+        foreground: "#DD4814"
+        foregroundText: "#F3F3E7"
+        field: "#FFFFFF"
+        fieldText: "#888888"
+    }
+}

=== added file 'modules/Ubuntu/Components/Themes/SuruGradient/SuruGradient.pro'
--- modules/Ubuntu/Components/Themes/SuruGradient/SuruGradient.pro	1970-01-01 00:00:00 +0000
+++ modules/Ubuntu/Components/Themes/SuruGradient/SuruGradient.pro	2013-07-11 13:40:11 +0000
@@ -0,0 +1,27 @@
+TEMPLATE = subdirs
+
+uri = Ubuntu.Components.Themes.SuruGradient
+installPath = $$[QT_INSTALL_QML]/$$replace(uri, \\., /)
+
+PARENT_THEME_FILE = parent_theme
+QMLDIR_FILE = qmldir
+QML_FILES = *.qml
+ARTWORK_FILES += artwork/*.png \
+                 artwork/*.svg \
+                 artwork/*.sci
+
+parent_theme_file.path = $$installPath
+parent_theme_file.files = $$PARENT_THEME_FILE
+
+qmldir_file.path = $$installPath
+qmldir_file.files = $$QMLDIR_FILE
+
+qml_files.path = $$installPath
+qml_files.files = $$QML_FILES
+
+artwork_files.path = $$installPath/artwork
+artwork_files.files = $$ARTWORK_FILES
+
+
+INSTALLS += parent_theme_file qmldir_file qml_files artwork_files
+OTHER_FILES += $$PARENT_THEME_FILE $$QMLDIR_FILE $$QML_FILES $$ARTWORK_FILES

=== added file 'modules/Ubuntu/Components/Themes/SuruGradient/parent_theme'
--- modules/Ubuntu/Components/Themes/SuruGradient/parent_theme	1970-01-01 00:00:00 +0000
+++ modules/Ubuntu/Components/Themes/SuruGradient/parent_theme	2013-07-05 14:34:00 +0000
@@ -0,0 +1,1 @@
+Ubuntu.Components.Themes.Ambiance

=== added file 'modules/Ubuntu/Components/Themes/SuruGradient/qmldir'
--- modules/Ubuntu/Components/Themes/SuruGradient/qmldir	1970-01-01 00:00:00 +0000
+++ modules/Ubuntu/Components/Themes/SuruGradient/qmldir	2013-07-11 13:26:32 +0000
@@ -0,0 +1,1 @@
+module Ubuntu.Components.Themes.SuruGradient

=== modified file 'modules/Ubuntu/Components/Themes/Themes.pro'
--- modules/Ubuntu/Components/Themes/Themes.pro	2013-07-01 06:32:40 +0000
+++ modules/Ubuntu/Components/Themes/Themes.pro	2013-07-11 13:26:32 +0000
@@ -1,5 +1,7 @@
 TEMPLATE = subdirs
-SUBDIRS += Ambiance
+SUBDIRS += Ambiance \
+           SuruDark \
+           SuruGradient
 
 uri = Ubuntu.Components.Themes
 installPath = $$[QT_INSTALL_QML]/$$replace(uri, \\., /)

=== modified file 'modules/Ubuntu/Components/plugin/shapeitem.cpp'
--- modules/Ubuntu/Components/plugin/shapeitem.cpp	2013-07-09 15:21:04 +0000
+++ modules/Ubuntu/Components/plugin/shapeitem.cpp	2013-07-11 17:12:01 +0000
@@ -231,6 +231,8 @@
 
 void ShapeItem::updateFromImageProperties(QQuickItem* image)
 {
+    int alignment;
+
     // ShapeItem::stretched depends on image::fillMode
     QQuickImage::FillMode fillMode = (QQuickImage::FillMode)image->property("fillMode").toInt();
     if (fillMode == QQuickImage::PreserveAspectCrop) {
@@ -240,12 +242,26 @@
     }
 
     // ShapeItem::horizontalAlignment depends on image::horizontalAlignment
-    QQuickImage::HAlignment horizontalAlignment = (QQuickImage::HAlignment)image->property("horizontalAlignment").toInt();
-    setHorizontalAlignment((ShapeItem::HAlignment)horizontalAlignment);
+    int imageHorizontalAlignment = image->property("horizontalAlignment").toInt();
+    if (imageHorizontalAlignment == Qt::AlignLeft) {
+        alignment = ShapeItem::AlignLeft;
+    } else if (imageHorizontalAlignment == Qt::AlignRight) {
+        alignment = ShapeItem::AlignRight;
+    } else {
+        alignment = ShapeItem::AlignHCenter;
+    }
+    setHorizontalAlignment(static_cast<ShapeItem::HAlignment>(alignment));
 
     // ShapeItem::verticalAlignment depends on image::verticalAlignment
-    QQuickImage::VAlignment verticalAlignment = (QQuickImage::VAlignment)image->property("verticalAlignment").toInt();
-    setVerticalAlignment((ShapeItem::VAlignment)verticalAlignment);
+    int imageVerticalAlignment = image->property("verticalAlignment").toInt();
+    if (imageVerticalAlignment == Qt::AlignTop) {
+        alignment = ShapeItem::AlignTop;
+    } else if (imageVerticalAlignment == Qt::AlignBottom) {
+        alignment = ShapeItem::AlignBottom;
+    } else {
+        alignment = ShapeItem::AlignVCenter;
+    }
+    setVerticalAlignment(static_cast<ShapeItem::VAlignment>(alignment));
 }
 
 void ShapeItem::connectToPropertyChange(QObject* sender, const char* property,
@@ -274,7 +290,6 @@
     updateFromImageProperties(image);
 }
 
-
 void ShapeItem::setStretched(bool stretched)
 {
     if (stretched_ != stretched) {
@@ -350,6 +365,7 @@
     const QSGTexture* texture = provider ? provider->texture() : NULL;
     if (provider && !texture) {
         update();
+        delete old_node;
         return NULL;
     }
 

=== modified file 'modules/Ubuntu/Components/plugin/shapeitem.h'
--- modules/Ubuntu/Components/plugin/shapeitem.h	2013-07-01 12:54:42 +0000
+++ modules/Ubuntu/Components/plugin/shapeitem.h	2013-07-09 16:59:38 +0000
@@ -47,8 +47,8 @@
 
     enum Radius { SmallRadius, MediumRadius };
     enum Border { RawBorder, IdleBorder, PressedBorder };
-    enum HAlignment { AlignLeft = Qt::AlignLeft, AlignHCenter = Qt::AlignHCenter, AlignRight = Qt::AlignRight };
-    enum VAlignment { AlignTop = Qt::AlignTop, AlignVCenter = Qt::AlignVCenter, AlignBottom = Qt::AlignBottom };
+    enum HAlignment { AlignLeft = 0, AlignHCenter = 1, AlignRight = 2 };
+    enum VAlignment { AlignTop = 0, AlignVCenter = 1, AlignBottom = 2 };
 
     QColor color() const { return color_; }
     void setColor(const QColor& color);

=== modified file 'modules/Ubuntu/Components/plugin/ucubuntuanimation.cpp'
--- modules/Ubuntu/Components/plugin/ucubuntuanimation.cpp	2013-07-10 17:07:06 +0000
+++ modules/Ubuntu/Components/plugin/ucubuntuanimation.cpp	2013-07-11 15:14:38 +0000
@@ -53,14 +53,10 @@
  */
 
 UCUbuntuAnimation::UCUbuntuAnimation(QObject *parent) :
-    QObject(parent)
+    QObject(parent),
+    m_standardEasing(QEasingCurve::OutQuad),
+    m_StandardEasingReverse(QEasingCurve::InQuad)
 {
-    m_standardEasing.setType(QEasingCurve::BezierSpline);
-    m_standardEasing.addCubicBezierSegment(QPointF(0.2, 0.0), QPointF(0.4, 1.0),
-                                              QPointF(1.0, 1.0));
-    m_StandardEasingReverse.setType(QEasingCurve::BezierSpline);
-    m_StandardEasingReverse.addCubicBezierSegment(QPointF(0.6, 0.0), QPointF(0.8, 1.0),
-                                             QPointF(1.0, 1.0));
 }
 
 /*!

=== added file 'tests/unit/tst_components/tst_mainview.qml'
--- tests/unit/tst_components/tst_mainview.qml	1970-01-01 00:00:00 +0000
+++ tests/unit/tst_components/tst_mainview.qml	2013-07-10 16:58:55 +0000
@@ -0,0 +1,48 @@
+/*
+ * Copyright 2013 Canonical Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+import QtQuick 2.0
+import QtTest 1.0
+import Ubuntu.Components 0.1
+
+TestCase {
+    name: "MainViewAPI"
+
+    MainView {
+        id: mainView
+    }
+
+    function initTestCase() {
+        compare(mainView.active, true, "MainView always active.");
+        compare(mainView.automaticOrientation, false, "Automatic orientation off by default.");
+        compare(mainView.applicationName, "", "Application name is empty string by default.");
+    }
+
+    function test_automaticOrientation() {
+        mainView.automaticOrientation = true;
+        compare(mainView.automaticOrientation, true, "Automatic orientation can be enabled.");
+        mainView.automaticOrientation = false;
+        compare(mainView.automaticOrientation, false, "Automaic orientation can be disabled.");
+    }
+
+    function test_applicationName() {
+        var appName = "testAppName";
+        mainView.applicationName = appName;
+        compare(mainView.applicationName, appName, "Applicatin name can be set.");
+        mainView.applicationName = "";
+        compare(mainView.applicationName, "", "Application name can be unset.");
+    }
+}

